pub struct Prefix<'a>(/* private fields */);Expand description
The representation of the prefix of a TermId.
Examples
Prefix can be obtained from a TermId:
use ontolius::TermId;
let seizure: TermId = "HP:0001250".parse().unwrap();
let prefix = seizure.prefix();Prefix can be tested for equality with a &str or with another prefix.
let arachnodactyly: TermId = "HP:0001166".parse().unwrap();
assert!(&prefix == "HP");
assert!(&arachnodactyly.prefix() == &prefix);Prefix implements PartialOrd and Ord traits.
Note that no particular order (e.g. alphabetical) is guaranteed.
Only that the ordering is defined.
Prefix can be hashed (Hash).
Prefix implements std::fmt::Debug and Display.
assert_eq!(prefix.to_string(), String::from("HP"));Trait Implementations
Sourceimpl Ord for Prefix<'_>
impl Ord for Prefix<'_>
Sourceimpl PartialEq<str> for Prefix<'_>
Prefix can be tested for equality with a &str.
impl PartialEq<str> for Prefix<'_>
Prefix can be tested for equality with a &str.
use ontolius::TermId;
let term_id: TermId = "HP:0001250".parse().unwrap();
assert!(&term_id.prefix() == "HP");Sourceimpl<'a> PartialOrd for Prefix<'a>
impl<'a> PartialOrd for Prefix<'a>
impl<'a> Eq for Prefix<'a>